# -*- coding: utf-8 -*-
"""
Created on Thu May 19 23:51:35 2022

@author: oriol
"""

import requests
import pandas as pd
import numpy as np
import time

series_endpoint = 'https://www.econdb.com/api/series/'

def get(code, freq=None):
    ts = pd.read_csv(
        '%s?ticker=[%s]&format=csv' %
        (series_endpoint, ','.join(code) if isinstance(code, list) else code),
        index_col='Date', parse_dates=['Date'])
    if freq == 'M':
        ts = ts.groupby(ts.index.map(lambda x: x.replace(day=1))).mean()
    return ts

def yahoo(code):
    ts = (
        pd.read_csv(
        'https://query1.finance.yahoo.com/v7/finance/download/%s?'
        'period1=1400000000&period2=%d&interval=1d&events=history'
        '&includeAdjustedClose=true' % (code, time.time() // 100 *100),
        date_parser='Date').set_index('Date')['Adj Close'])
    return ts



# -*- coding: utf-8 -*-
"""
Created on Fri May 20 12:30:58 2022

@author: oriol
"""

import pandas as pd
from prognosis.helper import get


groups = {
    'national_accounts':
        ['RGDP%s', 'RPRC%s', 'RPUC%s', 'RGFCF%s', 'REXP%s','RIMP%s'],
    'prices': ['CPI%s', 'PPI%s'],
    'government': ['GSPE%s', 'GREV%s', 'GBAL%s', 'GDEBT%s'],
    'monthly_trade': ['EXPMON%s', 'IMPMON%s'],
    'yield_curve': ['M3YD%s', 'Y10YD%s'],
}


class Country():
    def __init__(self, country_code):
        self.country_code = country_code

    def get_group(self, name):
        codes = [x % self.country_code for x in groups[name]]
        return get(codes)

    def national_accounts(self):
        return self.get_group('national_accounts')

    def prices(self):
        return self.get_group('prices')

    def monthly_trade(self):
        return self.get_group('monthly_trade')

    def government_accounts(self):
        return self.get_group('government')

    def yield_curve(self):
        return self.get_group('yield_curve')



# -*- coding: utf-8 -*-
"""
Created on Wed May 18 15:08:03 2022

@author: oriol
"""
import pandas as pd
from prognosis.helper import get, yahoo


# Daily yield - 10 year curve
usdyld = get('FRB_H15.37BF6.D.US', 'M')
usd3m = get('FRB_H15.4DCCD.M.US')
houus = get('HOUUS')
euryld = get('Y10YDDE')
gbpyld = get('Y10YDUK')
chyyld = get('Y10YDCN')
cpius = get('CPIUS')
cpicn = get('CPICN')
cpiuk = get('CPIUK')
cpiea = get('CPIEA')
eurusd = get('EURUSD')
gbpusd = get('GBPUSD')
usdcny = get('USDCNY')

impusd = get('IMPMONUS')
expusd = get('EXPMONUS')

oil = yahoo('CL=F')
gasoline = yahoo('RB=F')

m3us = get('M3US')
m3ea = get('M3DE')
gdpus = get('GDPUS')
gdebtus = get('GDEBTUS')


world_gdp = pd.read_csv('https://www.econdb.com/cross_section/GDP/',
                        index_col='ref_period', parse_dates=['ref_period'])
world_gdp = world_gdp.loc['2000-01-01':]
weights = (
    world_gdp.ffill().bfill().loc['2010-01-01'] /
    world_gdp.ffill().bfill().loc['2010-01-01'].sum())
wdgdp = (
    world_gdp.ffill().sum(axis=1) /
    (world_gdp.ffill().notnull() * weights).sum(axis=1))
ex_us = (wdgdp-gdpus['GDPUS']/4).dropna()
ex_us *= 4

dollar_adj_gdp = (gdpus['GDPUS'] + 0.1 * ex_us).dropna()

velocity = (dollar_adj_gdp/m3us['M3US']).dropna().to_frame(name='v')
usdyld = usdyld

inflation = cpius.pct_change(12)*100

(
velocity.join(
    (gdebtus['GDEBTUS']/gdpus['GDPUS']*10).to_frame(name='debt'))
.join(inflation).join((gdpus.pct_change(4)*100).dropna())
.join(usdyld).plot(secondary_y='v', figsize=(12, 8))
)

chm3 = (m3us.pct_change(12)*100).dropna()#usdyld
1 / ((usd3m + 4)/100)

real = (usd3m['FRB_H15.4DCCD.M.US'] - inflation['CPIUS']).to_frame(name='REAL')

df = inflation.join((gdpus.pct_change(4)*100).dropna()).join(chm3).join(usd3m).loc[pd.Timestamp('2000-01-01'):].dropna()



# -*- coding: utf-8 -*-

from setuptools import setup, find_packages


long_desc = '''Prognosis
=========

| This Python module provides a python wrapper around the API of Econdb.com.

Installation
------------

You can also find `Econdb on Github
<https://github.com/econdb/prognosis/>`_



Documentation
-------------

The documentation on installation, use and API description is found at econdb.com `documentation page. <https://www.econdb.com/documentation/inquisitor/>`_

Usage example
-------------



.. code:: python

	from prognosis import Country
	germany = Country('DE')

	### National Accounts
	nac = germany.national_accounts()

	### Consumer and producer prices
	prices = germany.prices()

	### Government accounts
	gov = germany.government_accounts()
'''


setup(
    name='prognosis',
    packages=find_packages(),
    version='0.0.2',
    author='Oriol Andres',
    description='A Python client for econdb.com/api/',
    long_description=long_desc,
    license='MIT License',
    author_email='admin@econdb.com',
    url='https://github.com/econdb/prognosis',
    download_url='https://github.com/econdb/prognosis/tarball/0.0.2',
    keywords=['data', 'economics', 'finance', 'api'],
    install_requires=["requests"],
    tests_require=["httmock"],
    test_suite="tests",
    classifiers=[
        "Programming Language :: Python",
        "Development Status :: 4 - Beta",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
        "Topic :: Software Development :: Libraries :: Python Modules",
        "Intended Audience :: Science/Research",
        "Topic :: Office/Business :: Financial :: Spreadsheet",
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
    ],
    extras_require={
        "pandas": ["pandas"]
    }
)
